Enum LogLevel
Source pub enum LogLevel {
Fatal,
Warning,
Info,
Debug,
}
Log levels supported by the logger.
Fatal log level, indicating a critical error.
Warning log level, indicating a potential issue.
Info log level, indicating general information.
Debug log level, indicating detailed debugging information.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.